@@ -7,6 +7,7 @@ pub use emphasize::emphasize_plugin;
 pub use heading::heading_plugin;
 pub use icon::icon_plugin;
 pub use input_guide::input_guide_plugin;
+pub use link::link_plugin;
 pub use list::list_plugin;
 pub use math::math_plugin;
 pub use quotation::quotation_plugin;
@@ -17,6 +18,7 @@ mod emphasize;
 mod heading;
 mod icon;
 mod input_guide;
+mod link;
 mod list;
 mod math;
 mod quotation;
